==> tiger-proxy-4.0.8-sources.jar: de/gematik/test/tiger/proxy/exceptions/TigerProxyRoutingException.java <==
/*
 *
 * Copyright 2021-2025 gematik GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * *******
 *
 * For additional notes and disclaimer from gematik and in case of changes by gematik find details in the "Readme" file.
 */
package de.gematik.test.tiger.proxy.exceptions;

import de.gematik.rbellogger.data.RbelElement;
import de.gematik.rbellogger.data.RbelHostname;
import java.util.concurrent.CompletableFuture;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
public class TigerProxyRoutingException extends TigerProxyException { // NOSONAR

  private CompletableFuture<RbelElement> routedMessage; // NOSONAR
  private final RbelHostname senderAddress; // NOSONAR
  private final RbelHostname receiverAddress; // NOSONAR

  public TigerProxyRoutingException(
      String errorMessage,
      RbelHostname senderAddress,
      RbelHostname receiverAddress,
      Throwable cause) {
    super(errorMessage, cause);
    this.receiverAddress = receiverAddress;
    this.senderAddress = senderAddress;
  }
}

==> tiger-proxy-4.1.1-sources.jar: de/gematik/test/tiger/proxy/exceptions/TigerProxyRoutingException.java <==
/*
 *
 * Copyright 2021-2025 gematik GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * *******
 *
 * For additional notes and disclaimer from gematik and in case of changes by gematik find details in the "Readme" file.
 */
package de.gematik.test.tiger.proxy.exceptions;

import de.gematik.rbellogger.data.RbelElement;
import de.gematik.rbellogger.util.RbelSocketAddress;
import java.util.concurrent.CompletableFuture;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
public class TigerProxyRoutingException extends TigerProxyException { // NOSONAR

  private CompletableFuture<RbelElement> routedMessage; // NOSONAR
  private final RbelSocketAddress senderAddress; // NOSONAR
  private final RbelSocketAddress receiverAddress; // NOSONAR

  public TigerProxyRoutingException(
      String errorMessage,
      RbelSocketAddress senderAddress,
      RbelSocketAddress receiverAddress,
      Throwable cause) {
    super(errorMessage, cause);
    this.receiverAddress = receiverAddress;
    this.senderAddress = senderAddress;
  }
}
